@@ -37,10 +37,10 @@
 #' )
 #' phylogeny <- ape::extract.clade(phylogeny, 18)
 #' studyTaxonList(x = phylogeny,
-#'                datasources = c("National Center for Biotechnology Information"))
+#'                datasources = c("GBIF Backbone Taxonomy"))
 #' @export
 studyTaxonList <- function(x = NULL,
-                           datasources = c("National Center for Biotechnology Information")) {
+                           datasources = "GBIF Backbone Taxonomy") {
   # Error check inputs (x).
   if (!class(x) == "phylo" & !(is.vector(class(x)) && class(x) == "character")) {
     warning(paste0("Target input invalid. Input must be of class\n",
