@@ -4,7 +4,8 @@ library(occCite)
 
 test_that("phylogeny can be read and manipulated as expected", {
   phylogeny <- ape::read.nexus(system.file("extdata/Fish_12Tax_time_calibrated.tre",
-                                           package = "occCite"))
+    package = "occCite"
+  ))
   phylogeny <- ape::extract.clade(phylogeny, 18)
 
   expect_true(class(phylogeny) == "phylo")
@@ -13,9 +14,10 @@ test_that("phylogeny can be read and manipulated as expected", {
 
 test_that("studyTaxonList works with a phylogeny", {
   phylogeny <- ape::read.nexus(system.file("extdata/Fish_12Tax_time_calibrated.tre",
-                                           package = "occCite"))
+    package = "occCite"
+  ))
   phylogeny <- ape::extract.clade(phylogeny, 18)
-  testResult <- studyTaxonList(x = phylogeny, datasources = c('National Center for Biotechnology Information'))
+  testResult <- studyTaxonList(x = phylogeny, datasources = c("National Center for Biotechnology Information"))
 
   expect_true(class(testResult) == "occCiteData")
   expect_true("userQueryType" %in% slotNames(testResult))
@@ -33,7 +35,7 @@ test_that("studyTaxonList works with a phylogeny", {
   expect_true("Input Name" %in% colnames(testResult@cleanedTaxonomy))
   expect_true("Best Match" %in% colnames(testResult@cleanedTaxonomy))
   expect_true("Taxonomic Databases w/ Matches"
-              %in% colnames(testResult@cleanedTaxonomy))
+  %in% colnames(testResult@cleanedTaxonomy))
 
   expect_true(length(testResult@occSources) == 0)
   expect_true(length(testResult@occCiteSearchDate) == 0)
@@ -42,7 +44,7 @@ test_that("studyTaxonList works with a phylogeny", {
 
 test_that("studyTaxonList works with a vector of species", {
   taxVector <- c("Buteo buteo", "Buteo buteo hartedi", "Buteo japonicus")
-  testResult <- studyTaxonList(x = taxVector, datasources = c('National Center for Biotechnology Information'))
+  testResult <- studyTaxonList(x = taxVector, datasources = c("National Center for Biotechnology Information"))
 
   expect_true(class(testResult) == "occCiteData")
   expect_true("userQueryType" %in% slotNames(testResult))
@@ -60,7 +62,7 @@ test_that("studyTaxonList works with a vector of species", {
   expect_true("Input Name" %in% colnames(testResult@cleanedTaxonomy))
   expect_true("Best Match" %in% colnames(testResult@cleanedTaxonomy))
   expect_true("Taxonomic Databases w/ Matches"
-              %in% colnames(testResult@cleanedTaxonomy))
+  %in% colnames(testResult@cleanedTaxonomy))
 
   expect_true(length(testResult@occSources) == 0)
   expect_true(length(testResult@occCiteSearchDate) == 0)
